# notionizer

Notionize your life with python module **notionizer**!


# Installation

**PIP Install(stable)**
```bash
pip Install notionizer 
```


**Github(develop)**

```
git clone https://github.com/kimsg1984/notionizer.git
cd notionizer
python3 setup.py install
```


# Usage

```
from notionizer import Notion
notion = Notion('notion_api_key')


```

# Reference